convert_palette: Convert the color of image to the color in the palette

Description Usage Arguments Value

View source: R/convert_palette.R

Description

Convert the color of image to the color in the palette

Usage

1

Arguments

img

An magick-image object.

palette

A palette.

Value

An magick-image object.


FinYang/pixelaRt documentation built on Dec. 17, 2021, 8:27 p.m.